@@ -27,6 +27,8 @@
 		void	clearError();
 		void	setError(const char *err);
 
+		void	flushWriteBuffer();
+
 		// clients
 		inetclientsocket	ics;
 		unixclientsocket	ucs;
@@ -38,7 +40,7 @@
 		bool	connected;
 
 		// connection
-		char			*server;
+		const char		*server;
 		unsigned short		listenerinetport;
 		unsigned short		connectioninetport;
 		char			*listenerunixport;
@@ -48,9 +50,9 @@
 		int			tries;
 
 		// authentication
-		char		*user;
+		const char	*user;
 		int		userlen;
-		char		*password;
+		const char	*password;
 		int		passwordlen;
 		bool		reconnect;
 
