@@ -299,6 +299,14 @@ class sqlrcursor:
         """
         return CSQLRelay.clearBinds(self.cursor)
 
+    def countBindVariables(self):
+	"""
+        Parses the previously prepared query,
+        counts the number of bind variables defined
+        in it and returns that number.
+	"""
+        return CSQLRelay.countBindVariables(self.cursor)
+
     def inputBind(self, variable, value, precision=0, scale=0):
         """
         Define an input bind varaible.
@@ -624,6 +632,48 @@ class sqlrcursor:
         """
         return CSQLRelay.getColumnIsPrimaryKey(self.cursor, col)
 
+    def getColumnIsUnique(self, col):
+        """
+        Returns 1 if the specified column is unique and
+        0 otherwise.
+        """
+        return CSQLRelay.getColumnIsUnique(self.cursor, col)
+
+    def getColumnIsPartOfKey(self, col):
+        """
+        Returns 1 if the specified column is part of a composite
+        key and 0 otherwise.
+        """
+        return CSQLRelay.getColumnIsPartOfKey(self.cursor, col)
+
+    def getColumnIsUnsigned(self, col):
+        """
+        Returns 1 if the specified column is an unsigned number
+        and 0 otherwise.
+        """
+        return CSQLRelay.getColumnIsUnsigned(self.cursor, col)
+
+    def getColumnIsZeroFilled(self, col):
+        """
+        Returns 1 if the specified column was created with the
+        zero-fill flag and 0 otherwise.
+        """
+        return CSQLRelay.getColumnIsZeroFilled(self.cursor, col)
+
+    def getColumnIsBinary(self, col):
+        """
+        Returns 1 if the specified column contains binary data
+        and 0 otherwise.
+        """
+        return CSQLRelay.getColumnIsBinary(self.cursor, col)
+
+    def getColumnIsAutoIncrement(self, col):
+        """
+        Returns 1 if the specified column auto-increments and
+        0 otherwise.
+        """
+        return CSQLRelay.getColumnIsAutoIncrement(self.cursor, col)
+
     def getLongest(self, col):
         """
         Returns the length of the specified column.  col may
