@@ -51,7 +51,7 @@ class mdbtoolsconnection : public sqlrconnection {
 		void	logOut();
 		bool	isTransactional();
 		bool	ping();
-		char	*identify();
+		const char	*identify();
 		bool	autoCommitOn();
 		bool	autoCommitOff();
 		bool	commit();
