@@ -3,6 +3,10 @@
 
 #include <rudiments/logger.h>
 
+#ifdef RUDIMENTS_NAMESPACE
+using namespace rudiments;
+#endif
+
 class debugfile {
 	public:
 				debugfile();
