@@ -1,5 +1,3 @@
-
-
 // Copyright (c) 2001  David Muse
 // See the file COPYING for more information.
 
@@ -12,7 +10,7 @@ sqlrcur	cur;
 sqlrcon	secondcon;
 sqlrcur	secondcur;
 
-void checkSuccessString(char *value, char *success) {
+void checkSuccessString(const char *value, const char *success) {
 
 	if (!success) {
 		if (!value) {
@@ -50,22 +48,22 @@ void checkSuccessInt(int value, int success) {
 
 int	main(int argc, char **argv) {
 
-	char	*dbtype;
+	const char	*dbtype;
 	char	*subvars[4]={"var1","var2","var3",NULL};
 	char	*subvalstrings[3]={"hi","hello","bye"};
 	long	subvallongs[3]={1,2,3};
 	double	subvaldoubles[3]={10.55,10.556,10.5556};
 	unsigned short	precs[3]={4,5,6};
 	unsigned short	scales[3]={2,3,4};
-	char	*numvar;
-	char	*stringvar;
-	char	*floatvar;
-	char	**cols;
-	char	**fields;
+	const char	*numvar;
+	const char	*stringvar;
+	const char	*floatvar;
+	const char * const *cols;
+	const char * const *fields;
 	int	port;
-	char	*socket;
+	const char	*socket;
 	int	id;
-	char	*filename;
+	const char	*filename;
 	long	*fieldlens;
 
 
