@@ -12,7 +12,7 @@ sqlrcur	cur;
 sqlrcon	secondcon;
 sqlrcur	secondcur;
 
-void checkSuccessString(char *value, char *success) {
+void checkSuccessString(const char *value, const char *success) {
 
 	if (!success) {
 		if (!value) {
@@ -49,7 +49,7 @@ void checkSuccessInt(int value, int success) {
 }
 
 int	main(int argc, char **argv) {
-	char	*dbtype;
+	const char	*dbtype;
 	char	*bindvars[6]={"1","2","3","4","5",NULL};
 	char	*bindvals[5]={"4","testchar4","testvarchar4","01-JAN-2004","testlong4"};
 	char	*subvars[4]={"var1","var2","var3",NULL};
@@ -58,15 +58,15 @@ int	main(int argc, char **argv) {
 	double	subvaldoubles[3]={10.55,10.556,10.5556};
 	unsigned short	precs[3]={4,5,6};
 	unsigned short	scales[3]={2,3,4};
-	char	*numvar;
-	char	*stringvar;
-	char	*floatvar;
-	char	**cols;
-	char	**fields;
+	const char	*numvar;
+	const char	*stringvar;
+	const char	*floatvar;
+	const char * const *cols;
+	const char * const *fields;
 	int	port;
-	char	*socket;
+	const char	*socket;
 	int	id;
-	char	*filename;
+	const char	*filename;
 	char	*arraybindvars[6]={"var1","var2","var3","var4","var5",NULL};
 	char	*arraybindvals[5]={"7","testchar7","testvarchar7","01-JAN-2007","testlong7"};
 	long	*fieldlens;
