@@ -48,6 +48,18 @@ class lago {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 		String	dbtype;
@@ -110,6 +122,7 @@ class lago {
 	
 		System.out.println("BIND BY NAME: ");
 		cur.prepareQuery("insert into testtable (testsmallint, testint, testfloat, testdouble, testdecimal, testchar, testvarchar, testdate, testtime) values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9)");
+		checkSuccess(cur.countBindVariables(),9);
 		cur.inputBind("var1",5);
 		cur.inputBind("var2",5);
 		cur.inputBind("var3",5.1,2,1);
