@@ -48,6 +48,18 @@ class msql {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 	
@@ -112,6 +124,7 @@ class msql {
 	
 		System.out.println("BIND BY NAME: ");
 		cur.prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8)");
+		checkSuccess(cur.countBindVariables(),8);
 		cur.inputBind("var1","char5");
 		cur.inputBind("var2","01-Jan-2005");
 		cur.inputBind("var3",5);
