@@ -48,6 +48,18 @@ class mysql {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 		String	dbtype;
@@ -111,6 +123,7 @@ class mysql {
 	
 		System.out.println("BIND BY NAME: ");
 		cur.prepareQuery("insert into testdb.testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9,:var10,:var11,:var12,:var13,:var14,:var15,:var16,:var17,:var18,null)");
+		checkSuccess(cur.countBindVariables(),18);
 		cur.inputBind("var1",5);
 		cur.inputBind("var2",5);
 		cur.inputBind("var3",5);
